# tmux-control

configure and control tmux

# setup

```Bash
sudo apt-get install cmus
sudo apt-get install elinks
sudo apt-get install htop
sudo apt-get install ranger
sudo apt-get install tmux

sudo pip install tmux_control
```

# usage

```Bash
tmux-control.py --help
```
